@@ -35,25 +35,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -64,25 +64,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -93,25 +93,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -122,25 +122,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -151,25 +151,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -180,25 +180,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 },
@@ -209,25 +209,25 @@ static char *xpm_color[7][27] = {
 "   ",
 "   ",
 "   ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
-" # ",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
+"###",
 "   ",
 "   "
 }
@@ -939,7 +939,7 @@ static const char * xpm_rtext[] = {
 "                        ",
 "                        "};
 
-static const char * xpm_bond[20][12] = {
+static const char * xpm_bond[22][12] = {
 {
 "24 9 2 1",
 "       c None",
@@ -1201,4 +1201,30 @@ static const char * xpm_bond[20][12] = {
 "                        ",
 "   ..................   ",
 "                        "
+},{
+"24 9 2 1",
+"       c None",
+".      c #505000",
+"                        ",
+"        ..........      ",
+"     ..           .     ",
+"   ..              .    ",
+"   ..              .    ",
+"     ..           .     ",
+"        ..........      ",
+"                        ",
+"                        "
+},{
+"24 9 2 1",
+"       c None",
+".      c #505000",
+"                        ",
+"        ..........      ",
+"     ..............     ",
+"   .................    ",
+"   .................    ",
+"     ..............     ",
+"        ..........      ",
+"                        ",
+"                        "
 }};
