@@ -121,6 +121,8 @@ add_struct (int x, int y, int tx, int ty, int bond, int smarked, int tmarked, in
 /* adds the data corresponding to a new bond */
 {
   struct data *last;
+  struct xy_co *coord;
+  int lx,ly;
 
   if (bond == 17)
     {
@@ -129,6 +131,26 @@ add_struct (int x, int y, int tx, int ty, int bond, int smarked, int tmarked, in
 		 tx, ty, 1, smarked,color);
       return;
     }
+  if (bond == 20)
+    {
+	coord=multi_bonds(x,y,tx+(tx-x),ty+(ty-y),60);
+	lx=coord->tx;
+	ly=coord->ty;
+	coord=multi_bonds(tx+tx-x,ty+ty-y,x,y,60);
+      add_spline (x, y, lx,ly, coord->x, coord->y,
+		 x, y , 0, smarked,color);
+      return;
+    }
+  if (bond == 21)
+    {
+	coord=multi_bonds(x,y,tx+(tx-x),ty+(ty-y),60);
+	lx=coord->tx;
+	ly=coord->ty;
+	coord=multi_bonds(tx+tx-x,ty+ty-y,x,y,60);
+      add_spline (x, y, lx,ly, coord->x, coord->y,
+		 x, y , -1, smarked,color);
+      return;
+    }
 
   new->x = x;
   new->y = y;
