@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.7"
+#define VERSION "1.6.9"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -222,9 +222,10 @@ extern int export_latex_pic(char *filename, float scalefactor);
 extern int export_ps_pic(char *filename, float scalefactor);
 extern int print_ps_pic(char *filename);
 extern int export_fw(char *filename);
-extern int export_mdl_mol(FILE *fp);
+extern int export_mdl_mol(FILE *fp, int topipe);
 extern int export_emf(char *filename);
 extern int export_sxd(char *filename);
+extern int export_babel(char *filename);
 extern int readrc(void);
 extern int writerc(void);
 extern void pdbrotate(int,int,int);
@@ -312,6 +313,9 @@ int importoffset=500;
 extern char **intype;
 extern char **inmode;
 extern int babelin;
+extern char **outtype;
+extern char **outmode;
+extern int babelout;
 char* babel;
 GdkGC *mygc[7],*background_gc;
 int curpen=0;
