@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.7"
+#define VERSION "1.6.9"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -226,7 +226,7 @@ extern int add_mol(char *filename);
 extern int export_bitmap(char *filename);
 extern int export_xfig(char *filename);
 extern int export_svg(char *filename);
-extern int export_mdl_mol(FILE *fp);
+extern int export_mdl_mol(FILE *fp, int topipe);
 extern int import_mdl_mol(char *filename,int skip);
 extern int import_pdb(char *filename);
 extern int export_latex_pic(char *filename,float scalefactor);
@@ -241,6 +241,7 @@ extern void xfig_spline (FILE *, int , int , int , int , int , int , int , int ,
 extern int exfig(FILE*, int);
 extern int export_fw(char*);
 extern int export_sxd(char*);
+extern int export_babel(char*);
 extern int readrc(void);
 extern int writerc(void);
 extern void check_fig2dev(void);
@@ -276,8 +277,10 @@ extern int importoffset;
 char **intype;
 char **inmode;
 int babelin;
+char **outtype;
+char **outmode;
+int babelout;
 extern char *babel;
-char babelout[4];
 extern GdkGC *mygc[7],*background_gc;
 extern int curpen;
 extern int gridtype;
