@@ -259,18 +259,18 @@ Display_Mol ()
 	  break;
 	case 18:
 	  {			/*triple, equal lengths */
-	  Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty, hpc->smarked + hpc->tmarked,hpc->color);	/*single */
-	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist);
+	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, 2*db_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
+	  Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty, hpc->smarked + hpc->tmarked,hpc->color);	/*single */
 	  }
 	  break;
 	case 19:
 	  {			/*quadruple */
-	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist+1);
+	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist+3);
 	    tmpx1=coord->x;
 	    tmpy1=coord->y;
             tmptx1=coord->tx;
@@ -280,13 +280,13 @@ Display_Mol ()
 	    tmpy2=coord->y;
             tmptx2=coord->tx;
             tmpty2=coord->ty;
-	    coord = center_double_bond (tmpx1, tmpy1, tmptx1, tmpty1, db_dist-1);
+	    coord = center_double_bond (tmpx1, tmpy1, tmptx1, tmpty1, db_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
-	    coord = center_double_bond (tmpx2, tmpy2,tmptx2, tmpty2, db_dist-1);
+	    coord = center_double_bond (tmpx2, tmpy2,tmptx2, tmpty2, db_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
@@ -1024,7 +1024,8 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
   int variance[MAXCL];
   gchar *c;
 #ifdef GTK2
-  gchar *l="       ";
+  int dummy;
+  gchar *l="  ";
   gunichar hc, hl;
   gunichar text[MAXCL];
   gunichar symbol[MAXCL];
@@ -1076,9 +1077,9 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
   a = gdk_char_height (font[fontsize], 'X');
   ha = gdk_char_height (font[fontsize], 'x') / 2;
   n = (int)strlen (c);
+  tw = gdk_char_width (font[fontsize], 'x') ;
 #endif
 
-
 #ifdef GTK2
   for (d = 0; d < n; d++)
     {
@@ -1087,7 +1088,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
       bold[d]=FALSE;
       
       hc = g_utf8_get_char(c);
-      
+
       if (shiftall != 0)
 	{
 	  if (hc == '}')
@@ -1117,6 +1118,8 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 	      else
 		{
 		  variance[d] = 0;
+		  n=d;
+		  continue;
 		}
 	    }
 	}
@@ -1126,6 +1129,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 	{
 	  symbol[d] = TRUE;
 	  text[d] = hl;
+          c = g_utf8_next_char(c);
 	  --n;
 	}
 
@@ -1133,6 +1137,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 	{
 	  slanted[d] = TRUE;
 	  text[d] = hl;
+          c = g_utf8_next_char(c);
 	  --n;
 	}
 
@@ -1140,6 +1145,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 	{
 	  bold[d] = TRUE;
 	  text[d] = hl;
+          c = g_utf8_next_char(c);
 	  --n;
 	}
 
@@ -1233,7 +1239,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 #ifdef GTK2
               pango_layout_set_text(thelayout,l,-1);
               pango_layout_set_font_description(thelayout,smallfont[fontsize]);
-              pango_layout_get_pixel_size(thelayout, &tw, &a);
+              pango_layout_get_pixel_size(thelayout, &tw, &dummy);
 #else             
 	      tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
 #endif
@@ -1242,7 +1248,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 		tw = gdk_char_width (ssymbfont[fontsize], text[d]);
@@ -1265,7 +1271,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 #ifdef GTK2
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,font[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
 #else
 	      tw = 1 + gdk_char_width (font[fontsize], text[d]);
 #endif
@@ -1274,7 +1280,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,symbfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 		tw = gdk_char_width (symbfont[fontsize], text[d]);
@@ -1284,7 +1290,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,boldfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	      	tw = gdk_char_width (boldfont[fontsize], text[d]);
@@ -1294,12 +1300,12 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,slfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 		tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
 #endif
-	      if (save_x < x)
+	      if (save_x < x) 
 		{
 		  if (sub_lastx < sup_lastx)
 		    x = sup_lastx;
@@ -1312,6 +1318,10 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 	  if (chl == 0)
 	    chl = tw;
 	}
+	if (x != sub_lastx || x != sup_lastx) save_x+= tw; // if the label ends with a sub/superscripted character,
+							   // add its length to the current position (which is before
+							   // the sub/superscript to allow vertical alignment of simultaneous
+							   // sub- and superscripts
       textl = save_x;
       switch (direct)
 	{
@@ -1332,13 +1342,17 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
   save_x = sub_lastx = sup_lastx = x;
   for (d = 0; d < n; d++)
     {
+#ifdef GTK2
+//          l = g_locale_to_utf8((const gchar*) &text[d],1,NULL,NULL,NULL);
+	g_unichar_to_utf8((gunichar)text[d], l);
+#endif          
       if (variance[d])
 	{
 #ifdef GTK2
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,smallfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	  tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
@@ -1348,7 +1362,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	    tw = gdk_char_width (ssymbfont[fontsize], text[d]);
@@ -1371,7 +1385,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 #ifdef GTK2
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,font[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
 #else                
 	  tw = 1 + gdk_char_width (font[fontsize], text[d]);
 #endif
@@ -1380,7 +1394,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,symbfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	    tw = gdk_char_width (symbfont[fontsize], text[d]);
@@ -1390,7 +1404,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,boldfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	    tw = gdk_char_width (boldfont[fontsize], text[d]);
@@ -1400,7 +1414,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,slfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	    tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
@@ -1425,17 +1439,17 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 		    tw + 8 * size_factor, a + 10 * size_factor, 0, 360 * 64);
 	else
       gdk_draw_arc (picture, background_gc, 1,
-		    x - 5 * size_factor,
-		    y - a + ha - 5 * size_factor + variance[d],
-		    tw + 8 * size_factor, a + 10 * size_factor, 0, 360 * 64);
-    }
+		    x - 2 * size_factor,
+		    y -a + ha + size_factor * variance[d],
+		    tw + 8 * size_factor, a + 2 * size_factor, 0, 360 * 64);
       x = x + tw;
+      }
     }
 
   n = nch;
   x = hx;
 
-#ifdef GTK2  
+#ifdef GTK2
   y -= a ;
 #endif
   
@@ -1444,7 +1458,11 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
     {
 #ifdef GTK2
 	memset(l,0,sizeof(l));
+//#ifdef GTK2
+//          l = g_locale_to_utf8((const gchar*) &text[d],1,NULL,NULL,NULL);
+//	memset(l,0,2);
 	g_unichar_to_utf8((gunichar)text[d], l);
+
 	if (symbol[d]) {
 	unsigned int unicodechar=text[d]+848;
 	
@@ -1548,7 +1566,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,smallfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	  tw = gdk_char_width (smallfont[fontsize], text[d]) + 2;
@@ -1558,7 +1576,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
                 {
                   pango_layout_set_text(thelayout,l,-1);
                   pango_layout_set_font_description(thelayout,ssymbfont[fontsize]);
-                  pango_layout_get_pixel_size(thelayout, &tw, &a);
+                  pango_layout_get_pixel_size(thelayout, &tw, &dummy);
                 }
 #else                
 	    tw = gdk_char_width (ssymbfont[fontsize], text[d]);
@@ -1614,7 +1632,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
 #ifdef GTK2
               pango_layout_set_text(thelayout,l,-1);
               pango_layout_set_font_description(thelayout,font[fontsize]);
-              pango_layout_get_pixel_size(thelayout,&tw,&a);
+              pango_layout_get_pixel_size(thelayout,&tw,&dummy);
 #else
 	  tw = 1 + gdk_char_width (font[fontsize], text[d]);
 #endif	  
@@ -1623,7 +1641,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
             {
               pango_layout_set_text(thelayout,l,-1);
               pango_layout_set_font_description(thelayout,symbfont[fontsize]);
-              pango_layout_get_pixel_size(thelayout,&tw,&a);
+              pango_layout_get_pixel_size(thelayout,&tw,&dummy);
              } 
 #else
 	    tw = gdk_char_width (symbfont[fontsize], text[d]);
@@ -1633,7 +1651,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
             {
               pango_layout_set_text(thelayout,l,-1);
               pango_layout_set_font_description(thelayout,boldfont[fontsize]);
-              pango_layout_get_pixel_size(thelayout,&tw,&a);
+              pango_layout_get_pixel_size(thelayout,&tw,&dummy);
              } 
 #else
 	    tw = gdk_char_width (boldfont[fontsize], text[d]);
@@ -1643,7 +1661,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
             {
               pango_layout_set_text(thelayout,l,-1);
               pango_layout_set_font_description(thelayout,slfont[fontsize]);
-              pango_layout_get_pixel_size(thelayout,&tw,&a);
+              pango_layout_get_pixel_size(thelayout,&tw,&dummy);
              } 
 #else
 	    tw = 1 + gdk_char_width (slfont[fontsize], text[d]);
